pilot.filemanagement.s3_adaptor

Package pilot :: Package filemanagement :: Module s3_adaptor |

# Module s3_adaptor

source code

Amazon S3 based File Transfer Implementation

Classes
| S3FileAdaptor BigData File Management for Pilot Data Supports pilot data on top of S3 and Eucalyptus Walrus

Functions
test_walrus() | source code
test_swift() | source code
test_s3import() | source code
test_s3import_via_pilotapi() | source code

Variables
| AWS_ACCESS_KEY_ID = `None` hash(x)
| AWS_SECRET_ACCESS_KEY = `None` hash(x)
| __package__ = ``'``pilot.filemanagement``'``